/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.utils.toast;

import org.pepstock.charba.client.resources.AbstractInjectableResource;
import org.pepstock.charba.client.resources.ResourceName;

/**
 * Contains the content of <code>charba.toast.min.js</code> to inject.<br>
 * 
 * @author Andrea "Stock" Stocchero
 *
 */
final class ToastJsUtilResource extends AbstractInjectableResource {

	// encoded javascript content of charba.toast.min.js
	private static final String[] CONTENT = {
		"var $jscomp={scope:{},getGlobal:function($maybeGlobal$$){return\"undefined\"!=typeof window&&window===$maybeGlobal$$?$maybeGlobal$$:\"undefined\"!=typeof global?global:$maybeGlobal$$}};$jscomp.global=$jscomp.getGlobal(this);$jscomp.patches={};",
		"$jscomp.patch=function $$jscomp$patch$($target$$,$patch$$){($jscomp.patches[$target$$]=$jscomp.patches[$target$$]||[]).push($patch$$);for(var $obj$$=$jscomp.global,$property$$=$target$$.split(\".\"),$i$$=0;$i$$<$property$$.length-1&&$obj$$;$i$$++)$obj$$=$obj$$[$property$$[$i$$]];$property$$=$property$$[$property$$.length-1];$obj$$&&$obj$$[$property$$]instanceof Function&&($obj$$[$property$$]=$patch$$($obj$$[$property$$]))};$jscomp.SYMBOL_PREFIX=\"jscomp_symbol_\";",
		"$jscomp.initSymbol=function $$jscomp$initSymbol$(){$jscomp.initSymbol=function $$jscomp$initSymbol$(){};if(!$jscomp.global.Symbol){$jscomp.global.Symbol=$jscomp.Symbol;var $symbols$$=[],$removeSymbolsPatch$$=function $$removeSymbolsPatch$$$($orig$$){return function($names_target$$){$symbols$$=[];$names_target$$=$orig$$($names_target$$);for(var $result$$=[],$i$$=0,$len$$=$names_target$$.length;$i$$<$len$$;$i$$++){var $JSCompiler_inline_result$$6_name$$;a:if($JSCompiler_inline_result$$6_name$$=$names_target$$[$i$$],",
		"$JSCompiler_inline_result$$6_name$$.length<$jscomp.SYMBOL_PREFIX.length)$JSCompiler_inline_result$$6_name$$=!1;else{for(var $i$$0$$=0;$i$$0$$<$jscomp.SYMBOL_PREFIX.length;$i$$0$$++)if($JSCompiler_inline_result$$6_name$$[$i$$0$$]!=$jscomp.SYMBOL_PREFIX[$i$$0$$]){$JSCompiler_inline_result$$6_name$$=!1;break a}$JSCompiler_inline_result$$6_name$$=!0}$JSCompiler_inline_result$$6_name$$?$symbols$$.push($names_target$$[$i$$]):$result$$.push($names_target$$[$i$$])}return $result$$}};$jscomp.patch(\"Object.keys\",",
		"$removeSymbolsPatch$$);$jscomp.patch(\"Object.getOwnPropertyNames\",$removeSymbolsPatch$$);$jscomp.patch(\"Object.getOwnPropertySymbols\",function($orig$$){return function($target$$){$removeSymbolsPatch$$.unused=Object.getOwnPropertyNames($target$$);$symbols$$.push.apply($orig$$($target$$));return $symbols$$}})}};$jscomp.symbolCounter_=0;$jscomp.Symbol=function $$jscomp$Symbol$($description$$){return $jscomp.SYMBOL_PREFIX+$description$$+$jscomp.symbolCounter_++};",
		"$jscomp.initSymbolIterator=function $$jscomp$initSymbolIterator$(){$jscomp.initSymbol();$jscomp.global.Symbol.iterator||($jscomp.global.Symbol.iterator=$jscomp.global.Symbol(\"iterator\"));$jscomp.initSymbolIterator=function $$jscomp$initSymbolIterator$(){}};",
		"$jscomp.makeIterator=function $$jscomp$makeIterator$($iterable$$){$jscomp.initSymbolIterator();var $iteratorFunction$$=$iterable$$[Symbol.iterator];if($iteratorFunction$$)return $iteratorFunction$$.call($iterable$$);var $index$$=0;return{next:function(){return $index$$<$iterable$$.length?{done:!1,value:$iterable$$[$index$$++]}:{done:!0}}}};",
		"CharbaToast={init:function $CharbaToast$init$(){var $container$$=document.createElement(\"div\");$container$$.id=\"ct-container\";document.body.appendChild($container$$);CharbaToast.create=function $CharbaToast$create$($pId$$,$$jscomp$iter$0_font$$,$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$,$pOptions_wrapper$$,$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$){function $removeToast$$(){document.getElementById(\"ct-container\").removeChild($toasting$$);var $style$$=document.querySelector(\"#style-\"+",
		"$toasting$$.id);$style$$&&$style$$.remove();$result$$.status=\"closed\";$result$$.dateTime.closed=Date.now();$result$$.element=$toasting$$;CharbaToast.currentOpenItems--;\"function\"===typeof $options$$.onClose&&$options$$.onClose.apply(this,[$result$$]);\"function\"===typeof CharbaToast.onClose&&CharbaToast.onClose.apply(this,[$result$$])}var $$jscomp$this$$=this,$result$$={id:$pId$$,title:$$jscomp$iter$0_font$$,label:$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$,dateTime:Object.assign({},",
		"$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$||{})},$$jscomp$key$item_hasTitle_item_itemElement_title$$=\"string\"===typeof $$jscomp$iter$0_font$$&&0<$$jscomp$iter$0_font$$.trim().length;$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$=Array.isArray($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$)&&0<$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.length;if(!$$jscomp$key$item_hasTitle_item_itemElement_title$$&&!$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$)return Object.assign($result$$,",
		"{status:\"invalid\",dateTime:{invalid:Date.now()}});var $options$$=Object.assign({},CharbaToast.defaults,CharbaToast.overrides,$pOptions_wrapper$$||{});$options$$.title=Object.assign({},CharbaToast.defaults.title,CharbaToast.overrides.title,$options$$.title);$options$$.label=Object.assign({},CharbaToast.defaults.label,CharbaToast.overrides.label,$options$$.label);$options$$.action=Object.assign({},CharbaToast.defaults.action,CharbaToast.overrides.action,$options$$.action);var $toasting$$=document.createElement(\"div\");",
		"$toasting$$.id=\"toast-\"+$pId$$;$toasting$$.className=\"ct-toast\";$pOptions_wrapper$$=document.createElement(\"div\");$pOptions_wrapper$$.style.borderRadius=$options$$.borderRadius+\"px\";$options$$.hideShadow&&($pOptions_wrapper$$.style.boxShadow=\"none\");$$jscomp$key$item_hasTitle_item_itemElement_title$$&&($$jscomp$key$item_hasTitle_item_itemElement_title$$=document.createElement(\"h4\"),$$jscomp$key$item_hasTitle_item_itemElement_title$$.className=\"ct-title\",$$jscomp$key$item_hasTitle_item_itemElement_title$$.innerHTML=",
		"$$jscomp$iter$0_font$$,\"string\"===typeof $options$$.title.color&&($$jscomp$key$item_hasTitle_item_itemElement_title$$.style.color=$options$$.title.color),\"object\"===typeof $options$$.title.font&&($$jscomp$iter$0_font$$=Object.assign({},CharbaToast.defaults.titleFont,$options$$.title.font),$$jscomp$iter$0_font$$=CharbaToast.helper.toFont.apply(this,[$$jscomp$iter$0_font$$]),$$jscomp$key$item_hasTitle_item_itemElement_title$$.style.font=$$jscomp$iter$0_font$$.string),$pOptions_wrapper$$.appendChild($$jscomp$key$item_hasTitle_item_itemElement_title$$));",
		"$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$&&($$jscomp$loop$5_hasLabel_pDateTime_rules_text$$=document.createElement(\"p\"),$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.className=\"ct-label\",$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.innerHTML=$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.join(\"<br/>\"),\"string\"===typeof $options$$.label.color&&($$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.style.color=$options$$.label.color),\"object\"===typeof $options$$.label.font&&",
		"($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$=Object.assign({},CharbaToast.defaults.labelFont,$options$$.label.font),$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$=CharbaToast.helper.toFont.apply(this,[$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$]),$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.style.font=$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.string),$pOptions_wrapper$$.appendChild($$jscomp$loop$5_hasLabel_pDateTime_rules_text$$));",
		"$options$$.icon&&$options$$.icon.src&&($pOptions_wrapper$$.classList+=\" img\",$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$=document.createElement(\"img\"),$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.src=$options$$.icon.src,$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.className=\"ct-icon\",$pOptions_wrapper$$.appendChild($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$));if(Array.isArray($options$$.actions)&&",
		"0<$options$$.actions.length){$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$=document.createElement(\"div\");$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.className=\"ct-actions\";\"string\"===typeof $options$$.align&&($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.style.textAlign=$options$$.align);$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$={};$$jscomp$iter$0_font$$=$jscomp.makeIterator($options$$.actions);for($$jscomp$key$item_hasTitle_item_itemElement_title$$=",
		"$$jscomp$iter$0_font$$.next();!$$jscomp$key$item_hasTitle_item_itemElement_title$$.done;$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$={actionOption:$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption},$$jscomp$key$item_hasTitle_item_itemElement_title$$=$$jscomp$iter$0_font$$.next())if($$jscomp$key$item_hasTitle_item_itemElement_title$$=$$jscomp$key$item_hasTitle_item_itemElement_title$$.value,\"string\"===typeof $$jscomp$key$item_hasTitle_item_itemElement_title$$.id&&\"string\"===typeof $$jscomp$key$item_hasTitle_item_itemElement_title$$.content&&",
		"\"function\"===typeof $$jscomp$key$item_hasTitle_item_itemElement_title$$.onClick){$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption=Object.assign({},$options$$.action,$$jscomp$key$item_hasTitle_item_itemElement_title$$);$$jscomp$key$item_hasTitle_item_itemElement_title$$=document.createElement(\"div\");$$jscomp$key$item_hasTitle_item_itemElement_title$$.className=\"ct-action\";$$jscomp$key$item_hasTitle_item_itemElement_title$$.innerHTML=$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.content;",
		"$$jscomp$key$item_hasTitle_item_itemElement_title$$.addEventListener(\"click\",function($$jscomp$loop$5$$){return function($event$$){$result$$.dateTime[$$jscomp$loop$5$$.actionOption.id]=Date.now();$$jscomp$loop$5$$.actionOption.onClick.apply($$jscomp$this$$,[$pId$$,$event$$])&&($result$$.actionId=$$jscomp$loop$5$$.actionOption.id,$toasting$$.hide.call())}}($$jscomp$loop$5_hasLabel_pDateTime_rules_text$$));\"string\"===typeof $$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.color&&($$jscomp$key$item_hasTitle_item_itemElement_title$$.style.color=",
		"$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.color);\"string\"===typeof $$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.backgroundColor&&($$jscomp$key$item_hasTitle_item_itemElement_title$$.style.background=$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.backgroundColor);\"string\"===typeof $$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.borderColor&&($$jscomp$key$item_hasTitle_item_itemElement_title$$.style.borderColor=$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.borderColor);",
		"$$jscomp$key$item_hasTitle_item_itemElement_title$$.style.borderWidth=Math.max($$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.borderWidth,0)+\"px\";\"string\"===typeof $$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.borderStyle&&($$jscomp$key$item_hasTitle_item_itemElement_title$$.style.borderStyle=$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.borderStyle);$$jscomp$key$item_hasTitle_item_itemElement_title$$.style.borderRadius=Math.max($$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.borderRadius,",
		"0)+\"px\";\"string\"===typeof $$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.color&&($$jscomp$key$item_hasTitle_item_itemElement_title$$.style.color=$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.color);if(\"object\"===typeof $$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.font){var $font$3_normFont$4$$=Object.assign({},CharbaToast.defaults.labelFont,$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$.actionOption.font),$font$3_normFont$4$$=CharbaToast.helper.toFont.apply(this,",
		"[$font$3_normFont$4$$]);$$jscomp$key$item_hasTitle_item_itemElement_title$$.style.font=$font$3_normFont$4$$.string}$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.appendChild($$jscomp$key$item_hasTitle_item_itemElement_title$$)}$pOptions_wrapper$$.appendChild($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$)}$options$$.hideProgressBar||($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$=document.createElement(\"style\"),$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.id=",
		"\"style-\"+$toasting$$.id,$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.type=\"text/css\",$$jscomp$loop$5_hasLabel_pDateTime_rules_text$$=document.createTextNode(\"\\n            @keyframes animate-\"+$pId$$+\" {\\n              0% {\\n                width: 100%\\n              }\\n              100% {\\n                width: 0%;\\n              }\\n            }\\n        \"),$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.appendChild($$jscomp$loop$5_hasLabel_pDateTime_rules_text$$),",
		"document.getElementsByTagName(\"head\")[0].appendChild($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$),$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$=document.createElement(\"div\"),$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.classList=\"progress-bar\",$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.style.animationName=\"animate-\"+$pId$$,$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.style.animationDuration=",
		"$options$$.timeout/1E3+\"s\",$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.style.animationTimingFunction=\"linear\",$actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.style.animationFillMode=\"forwards\",$options$$.progressBarType&&($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.classList+=\" \"+$options$$.progressBarType),$options$$.progressBarHeight&&($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$.style.height=",
		"$options$$.progressBarHeight+\"px\"),$pOptions_wrapper$$.appendChild($actionsContainer_cssAnimation_font$1_icon_normFont$2_pLabel_progressBar$$));\"function\"===typeof $options$$.onClick&&$toasting$$.addEventListener(\"click\",function($event$$){\"ct-action\"!==$event$$.target.className&&$options$$.onClick.apply($$jscomp$this$$,[$pId$$,$event$$])});$toasting$$.hide=function $$toasting$$$hide$(){$toasting$$.timeoutId&&clearTimeout($toasting$$.timeoutId);$toasting$$.className+=\" ct-fadeOut\";$toasting$$.addEventListener(\"animationend\",",
		"$removeToast$$,!1);return null};$options$$.autoHide&&($toasting$$.timeoutId=setTimeout($toasting$$.hide,$options$$.timeout+200));$pOptions_wrapper$$.className=$options$$.type?$pOptions_wrapper$$.className+(\" ct-\"+$options$$.type):$pOptions_wrapper$$.className+\" ct-default\";$toasting$$.addEventListener(\"click\",function($event$$){\"ct-action\"!==$event$$.target.className&&($options$$.modifierKey&&!$event$$[$options$$.modifierKey+\"Key\"]||$toasting$$.hide.call())});$toasting$$.appendChild($pOptions_wrapper$$);",
		"document.getElementById(\"ct-container\").appendChild($toasting$$);$result$$.status=\"opened\";$result$$.dateTime.opened=Date.now();CharbaToast.currentOpenItems++;\"function\"===typeof $options$$.onOpen&&$options$$.onOpen.apply(this,[$result$$]);$result$$.toasting=$toasting$$;return $result$$}},create:function $CharbaToast$create$(){console.error(\"DOM has not finished loading.\\n\\tInvoke create method when DOMs readyState is complete\")},helper:{lineHeightRegExp:new RegExp(/^(normal|(\\d+(?:\\.\\d+)?)(px|em|%)?)$/),",
		"fontStyleRegExp:new RegExp(/^(normal|italic|initial|inherit|unset|(oblique( -?[0-9]?[0-9]deg)?))$/),toLineHeight:function $CharbaToast$helper$toLineHeight$($value$$,$size$$){var $matches$$=(\"\"+$value$$).match(CharbaToast.helper.lineHeightRegExp);if(!$matches$$||\"normal\"===$matches$$[1])return 1.2*$size$$;$value$$=+$matches$$[2];switch($matches$$[3]){case \"px\":return $value$$;case \"%\":$value$$/=100}return $size$$*$value$$},toFont:function $CharbaToast$helper$toFont$($font$$4_options$$){var $size$$=",
		"$font$$4_options$$.size;\"string\"===typeof $size$$&&($size$$=parseInt($size$$,10));var $style$$=$font$$4_options$$.style;$style$$&&!(\"\"+$style$$).match(CharbaToast.helper.fontStyleRegExp)&&($style$$=\"\");$font$$4_options$$={family:$font$$4_options$$.family,lineHeight:CharbaToast.helper.toLineHeight.apply(this,[$font$$4_options$$.lineHeight,$size$$]),size:$size$$,style:$style$$,weight:$font$$4_options$$.weight,string:\"\"};$font$$4_options$$.string=($font$$4_options$$.style?$font$$4_options$$.style+\" \":",
		"\"\")+($font$$4_options$$.weight?$font$$4_options$$.weight+\" \":\"\")+$font$$4_options$$.size+\"px \"+$font$$4_options$$.family;return $font$$4_options$$}},clone:function $CharbaToast$clone$($source$$){if(Array.isArray($source$$))return $source$$.map(CharbaToast.clone);if(\"object\"===typeof $source$$){for(var $target$$={},$keys$$=Object.keys($source$$),$klen$$=$keys$$.length,$k$$=0;$k$$<$klen$$;++$k$$)$target$$[$keys$$[$k$$]]=CharbaToast.clone($source$$[$keys$$[$k$$]]);return $target$$}return $source$$},",
		"close:function $CharbaToast$close$($item$$){$item$$&&$item$$.toasting&&$item$$.toasting.hide&&$item$$.toasting.hide.call()},defaults:{align:void 0,actions:[],autoHide:!0,borderRadius:8,hideProgressBar:!1,hideShadow:!1,icon:void 0,onClick:void 0,onClose:void 0,onOpen:void 0,modifierKey:void 0,progressBarHeight:void 0,progressBarType:void 0,title:{color:void 0,font:void 0},label:{color:void 0,font:void 0},action:{name:void 0,onClick:void 0,backgroundColor:void 0,borderColor:void 0,borderWidth:0,borderStyle:\"none\",",
		"borderRadius:0,color:void 0,font:void 0},timeout:4E3,type:void 0,titleFont:{family:\"'Helvetica Neue', 'Helvetica', 'Arial', sans-serif\",lineHeight:1.2,size:15,style:\"normal\",weight:\"bold\"},labelFont:{family:\"'Helvetica Neue', 'Helvetica', 'Arial', sans-serif\",lineHeight:\"20px\",size:14,style:\"normal\",weight:\"normal\"}},overrides:{},onClose:void 0,currentOpenItems:0};Object.freeze(CharbaToast.defaults);Object.freeze(CharbaToast.helper);",
		"\"complete\"===document.readyState?CharbaToast.init():window.addEventListener(\"DOMContentLoaded\",CharbaToast.init);"
	};
	
	/**
	 * Creates the injectable resource with <code>charba.toast.min.js</code> content.
	 */
	ToastJsUtilResource() {
		super(ResourceName.TOAST_JS_UTIL, CONTENT);
	}

}
